@@ -108,7 +108,7 @@ DynAny_impl::insert_boolean (CORBA::Boolean value)
     CORBA::Any a;
     // take care for aliases of base types
     CORBA::TypeCode_var tc = _elements[_index]->type();
-    a.type (tc);
+    a.set_type (tc);
     a <<= CORBA::Any::from_boolean (value);
     _elements[_index]->from_any (a);
 }
@@ -123,7 +123,7 @@ DynAny_impl::insert_octet (CORBA::Octet value)
     CORBA::Any a;
     // take care for aliases of base types
     CORBA::TypeCode_var tc = _elements[_index]->type();
-    a.type (tc);
+    a.set_type (tc);
     a <<= CORBA::Any::from_octet (value);
     _elements[_index]->from_any (a);
 }
@@ -138,7 +138,7 @@ DynAny_impl::insert_char (CORBA::Char value)
     CORBA::Any a;
     // take care for aliases of base types
     CORBA::TypeCode_var tc = _elements[_index]->type();
-    a.type (tc);
+    a.set_type (tc);
     a <<= CORBA::Any::from_char (value);
     _elements[_index]->from_any (a);
 }
@@ -153,7 +153,7 @@ DynAny_impl::insert_wchar (CORBA::WChar value)
     CORBA::Any a;
     // take care for aliases of base types
     CORBA::TypeCode_var tc = _elements[_index]->type();
-    a.type (tc);
+    a.set_type (tc);
     a <<= CORBA::Any::from_wchar (value);
     _elements[_index]->from_any (a);
 }
@@ -168,7 +168,7 @@ DynAny_impl::insert_short (CORBA::Short value)
     CORBA::Any a;
     // take care for aliases of base types
     CORBA::TypeCode_var tc = _elements[_index]->type();
-    a.type (tc);
+    a.set_type (tc);
     a <<= value;
     _elements[_index]->from_any (a);
 }
@@ -183,7 +183,7 @@ DynAny_impl::insert_ushort (CORBA::UShort value)
     CORBA::Any a;
     // take care for aliases of base types
     CORBA::TypeCode_var tc = _elements[_index]->type();
-    a.type (tc);
+    a.set_type (tc);
     a <<= value;
     _elements[_index]->from_any (a);
 }
@@ -198,7 +198,7 @@ DynAny_impl::insert_long (CORBA::Long value)
     CORBA::Any a;
     // take care for aliases of base types
     CORBA::TypeCode_var tc = _elements[_index]->type();
-    a.type (tc);
+    a.set_type (tc);
     a <<= value;
     _elements[_index]->from_any (a);
 }
@@ -213,7 +213,7 @@ DynAny_impl::insert_longlong (CORBA::LongLong value)
     CORBA::Any a;
     // take care for aliases of base types
     CORBA::TypeCode_var tc = _elements[_index]->type();
-    a.type (tc);
+    a.set_type (tc);
     a <<= value;
     _elements[_index]->from_any (a);
 }
@@ -228,7 +228,7 @@ DynAny_impl::insert_ulong (CORBA::ULong value)
     CORBA::Any a;
     // take care for aliases of base types
     CORBA::TypeCode_var tc = _elements[_index]->type();
-    a.type (tc);
+    a.set_type (tc);
     a <<= value;
     _elements[_index]->from_any (a);
 }
@@ -243,7 +243,7 @@ DynAny_impl::insert_ulonglong (CORBA::ULongLong value)
     CORBA::Any a;
     // take care for aliases of base types
     CORBA::TypeCode_var tc = _elements[_index]->type();
-    a.type (tc);
+    a.set_type (tc);
     a <<= value;
     _elements[_index]->from_any (a);
 }
@@ -258,7 +258,7 @@ DynAny_impl::insert_float (CORBA::Float value)
     CORBA::Any a;
     // take care for aliases of base types
     CORBA::TypeCode_var tc = _elements[_index]->type();
-    a.type (tc);
+    a.set_type (tc);
     a <<= value;
     _elements[_index]->from_any (a);
 }
@@ -273,7 +273,7 @@ DynAny_impl::insert_double (CORBA::Double value)
     CORBA::Any a;
     // take care for aliases of base types
     CORBA::TypeCode_var tc = _elements[_index]->type();
-    a.type (tc);
+    a.set_type (tc);
     a <<= value;
     _elements[_index]->from_any (a);
 }
@@ -288,7 +288,7 @@ DynAny_impl::insert_longdouble (CORBA::LongDouble value)
     CORBA::Any a;
     // take care for aliases of base types
     CORBA::TypeCode_var tc = _elements[_index]->type();
-    a.type (tc);
+    a.set_type (tc);
     a <<= value;
     _elements[_index]->from_any (a);
 }
@@ -310,8 +310,8 @@ DynAny_impl::insert_string (const char* value)
         utc->length() < strlen (value))
         mico_throw (InvalidValue());
 
-    a.type (tc);
-    a <<= value;
+    a.set_type (tc);
+    a <<= CORBA::Any::from_string ((char *)value, utc->length());
     _elements[_index]->from_any (a);
 }
 
@@ -332,8 +332,8 @@ DynAny_impl::insert_wstring (const CORBA::WChar* value)
         utc->length() < xwcslen (value))
         mico_throw (InvalidValue());
 
-    a.type (tc);
-    a <<= value;
+    a.set_type (tc);
+    a <<= CORBA::Any::from_wstring ((CORBA::WChar *)value, utc->length());
     _elements[_index]->from_any (a);
 }
 
@@ -347,7 +347,7 @@ DynAny_impl::insert_reference (CORBA::Object_ptr value)
     CORBA::Any a;
     // take care for aliases of base types
     CORBA::TypeCode_var tc = _elements[_index]->type();
-    a.type (tc);
+    a.set_type (tc);
     if (_type->unalias()->kind() == CORBA::tk_objref)
         a <<= CORBA::Any::from_object (value, _type->name());
     else
@@ -365,7 +365,7 @@ DynAny_impl::insert_typecode (CORBA::TypeCode_ptr value)
     CORBA::Any a;
     // take care for aliases of base types
     CORBA::TypeCode_var tc = _elements[_index]->type();
-    a.type (tc);
+    a.set_type (tc);
     a <<= value;
     _elements[_index]->from_any (a);
 }
@@ -400,7 +400,7 @@ DynAny_impl::insert_any (const CORBA::Any &value)
     CORBA::Any a;
     // take care for aliases of base types
     CORBA::TypeCode_var tc = _elements[_index]->type();
-    a.type (tc);
+    a.set_type (tc);
     a <<= value;
     _elements[_index]->from_any (a);
 }
@@ -605,8 +605,9 @@ DynAny_impl::get_string ()
 
     update_element (_index);
     CORBA::Any_var a = _elements[_index]->to_any();
-    char *value;
-    if (!((CORBA::Any &)a >>= value))
+    const char *value;
+    CORBA::TypeCode_var tc = a->type();
+    if (!((CORBA::Any &)a >>= CORBA::Any::to_string (value, tc->unalias()->length())))
 	mico_throw (TypeMismatch ());
     return CORBA::string_dup (value);
 }
@@ -619,8 +620,9 @@ DynAny_impl::get_wstring ()
 
     update_element (_index);
     CORBA::Any_var a = _elements[_index]->to_any();
-    CORBA::WChar *value;
-    if (!((CORBA::Any &)a >>= value))
+    const CORBA::WChar *value;
+    CORBA::TypeCode_var tc = a->type();
+    if (!((CORBA::Any &)a >>= CORBA::Any::to_wstring (value, tc->unalias()->length())))
 	mico_throw (TypeMismatch ());
     return CORBA::wstring_dup (value);
 }
@@ -633,7 +635,7 @@ DynAny_impl::get_reference ()
 
     update_element (_index);
     CORBA::Any_var a = _elements[_index]->to_any();
-    CORBA::Object_ptr value;
+    CORBA::Object_var value;
     if (!((CORBA::Any &)a >>= CORBA::Any::to_object (value)))
 	mico_throw (TypeMismatch ());
     return CORBA::Object::_duplicate (value);
@@ -661,10 +663,12 @@ DynAny_impl::get_any ()
 
     update_element (_index);
     CORBA::Any_var a = _elements[_index]->to_any();
-    CORBA::Any *value = new CORBA::Any;
-    if (!((CORBA::Any &)a >>= *value))
+    const CORBA::Any *value;
+    if (!((CORBA::Any &)a >>= value))
 	mico_throw (TypeMismatch ());
-    return value;
+    CORBA::Any *retn = new CORBA::Any;
+    *retn = *value;
+    return retn;
 }
 
 DynamicAny::DynAny_ptr
@@ -675,10 +679,10 @@ DynAny_impl::get_dyn_any ()
 
     update_element (_index);
     CORBA::Any_var a = _elements[_index]->to_any();
-    CORBA::Any value;
+    const CORBA::Any* value;
     if (!((CORBA::Any &)a >>= value))
 	mico_throw (TypeMismatch ());
-    return _factory()->create_dyn_any (value);
+    return _factory()->create_dyn_any (*value);
 }
 
 CORBA::ValueBase *
@@ -764,7 +768,7 @@ DynBasic_impl::DynBasic_impl (CORBA::TypeCode_ptr tc)
 {
     _type = CORBA::TypeCode::_duplicate (tc);
     // take care for aliases of base types
-    _value.type (_type);
+    _value.set_type (_type);
     tc = tc->unalias ();
     switch (tc->kind()) {
     case CORBA::tk_void:
@@ -997,7 +1001,7 @@ DynEnum_impl::DynEnum_impl (CORBA::TypeCode_ptr tc)
 	mico_throw (DynamicAny::DynAnyFactory::InconsistentTypeCode ());
 
     _type = CORBA::TypeCode::_duplicate (tc);
-    _value.type (tc);
+    _value.set_type (tc);
     _value.enum_put (0);
 
     _elements.push_back (_duplicate (this));
@@ -1118,6 +1122,12 @@ DynStruct_impl::DynStruct_impl (const CORBA::Any &a)
 	CORBA::Any el;
 	CORBA::Boolean r = a.any_get (el);
 	assert (r);
+// Here it is needed to set the Any type after calling any_get()
+// else there is no deal with aliased typecodes.
+// Note that calling el.set_type() before calling any_get() doesn't resolve the alias problem.
+         CORBA::TypeCode_var member_tc = tc->member_type(i);
+         el.type(member_tc);
+//
 	_elements.push_back (_factory()->create_dyn_any (el));
     }
     if (_isexcept) {
@@ -1155,6 +1165,12 @@ DynStruct_impl::from_any (const CORBA::Any& value)
 	CORBA::Any el;
 	CORBA::Boolean r = value.any_get (el);
 	assert (r);
+// Here it is needed to set the Any type after calling any_get()
+// else there is no deal with aliased typecodes.
+// Note that calling el.set_type() before calling any_get() doesn't resolve the alias problem.
+	CORBA::TypeCode_var member_tc = tc2->member_type(i);
+	el.type(member_tc);
+//
 	_elements[i]->from_any (el);
     }
     if (_isexcept) {
@@ -1171,7 +1187,7 @@ DynStruct_impl::to_any ()
 {
     CORBA::Any *a = new CORBA::Any;
 
-    a->type (_type);
+    a->set_type (_type);
 
     if (_isexcept) {
 	CORBA::TypeCode_ptr tc = _type->unalias();
@@ -1268,7 +1284,7 @@ DynStruct_impl::set_members_as_dyn_any (
 	if (strlen (value[i].id) > 0 &&
             strcmp (tc->member_name(i), value[i].id))
 	    mico_throw (TypeMismatch ());
-	_elements[i]->assign (value[i].value);
+	_elements[i]->assign (value[i].value.in());
     }
     _index = _elements.size() > 0 ? 0 : -1;
 }
@@ -1308,6 +1324,12 @@ DynUnion_impl::DynUnion_impl (const CORBA::Any &a)
     CORBA::Any disc;
     r = a.any_get (disc);
     assert (r);
+// Here it is needed to set the Any type after calling any_get()
+// else there is no deal with aliased typecodes.
+// Note that calling el.set_type() before calling any_get() doesn't resolve the alias problem.
+    CORBA::TypeCode_var discr_tc = tc->discriminator_type();
+    disc.type(discr_tc);
+//
     _elements.push_back (_factory()->create_dyn_any (disc));
     _member_idx = tc->member_index (disc);
     if (_member_idx >= 0) {
@@ -1316,6 +1338,12 @@ DynUnion_impl::DynUnion_impl (const CORBA::Any &a)
 	CORBA::Any el;
 	r = a.any_get (el);
 	assert (r);
+// Here it is needed to set the Any type after calling any_get()
+// else there is no deal with aliased typecodes.
+// Note that calling el.set_type() before calling any_get() doesn't resolve the alias problem.
+	CORBA::TypeCode_var member_tc = tc->member_type(_member_idx);
+	el.type(member_tc);
+//
 	_elements.push_back (_factory()->create_dyn_any (el));
     } else {
 	// XXX what to do for implicit default case ???
@@ -1373,6 +1401,12 @@ DynUnion_impl::from_any (const CORBA::Any& value)
     CORBA::Any disc;
     r = value.any_get (disc);
     assert (r);
+// Here it is needed to set the Any type after calling any_get()
+// else there is no deal with aliased typecodes.
+// Note that calling el.set_type() before calling any_get() doesn't resolve the alias problem.
+    CORBA::TypeCode_var discr_tc = tc->discriminator_type();
+    disc.type(discr_tc);
+//
     _elements[0]->from_any (disc);
     update_element (1);
     if (_member_idx >= 0) {
@@ -1381,6 +1415,12 @@ DynUnion_impl::from_any (const CORBA::Any& value)
 	CORBA::Any el;
 	r = value.any_get (el);
 	assert (r);
+// Here it is needed to set the Any type after calling any_get()
+// else there is no deal with aliased typecodes.
+// Note that calling el.set_type() before calling any_get() doesn't resolve the alias problem.
+	CORBA::TypeCode_var member_tc = tc->member_type(_member_idx);
+	el.type(member_tc);
+//
 	_elements[1]->from_any (el);
     } else {
 	// XXX what to do for implicit default case ???
@@ -1397,7 +1437,7 @@ DynUnion_impl::to_any ()
 
     CORBA::Any *a = new CORBA::Any;
 
-    a->type (_type);
+    a->set_type (_type);
     CORBA::Boolean r = a->union_put_begin ();
     assert (r);
     CORBA::Any_var disc = _elements[0]->to_any ();
@@ -1456,7 +1496,7 @@ DynUnion_impl::set_to_default_member ()
 
     if (disc->kind() == CORBA::tk_enum) {
         CORBA::Any any;
-        any.type (disc);
+        any.set_type (disc);
         for (CORBA::ULong i = 0; i < disc->member_count(); ++i) {
             CORBA::Boolean r = any.enum_put (i);
             assert (r);
@@ -1607,7 +1647,7 @@ DynUnion_impl::set_to_no_active_member ()
 
     if (disc->kind() == CORBA::tk_enum) {
         CORBA::Any any;
-        any.type (disc);
+        any.set_type (disc);
         for (CORBA::ULong i = 0; i < disc->member_count(); ++i) {
             CORBA::Boolean r = any.enum_put (i);
             assert (r);
@@ -1815,6 +1855,12 @@ DynSequence_impl::DynSequence_impl (const CORBA::Any &a)
 	CORBA::Any el;
 	r = a.any_get (el);
 	assert (r);
+// Here it is needed to set the Any type after calling any_get()
+// else there is no deal with aliased typecodes.
+// Note that calling el.set_type() before calling any_get() doesn't resolve the alias problem.
+	CORBA::TypeCode_var member_tc = tc->content_type();
+	el.type(member_tc);
+//
 	_elements.push_back (_factory()->create_dyn_any (el));
     }
     r = a.seq_get_end ();
@@ -1844,6 +1890,12 @@ DynSequence_impl::from_any (const CORBA::Any& value)
 	CORBA::Any el;
 	r = value.any_get (el);
 	assert (r);
+// Here it is needed to set the Any type after calling any_get()
+// else there is no deal with aliased typecodes.
+// Note that calling el.set_type() before calling any_get() doesn't resolve the alias problem.
+	CORBA::TypeCode_var member_tc = tc->unalias()->content_type();
+	el.type(member_tc);
+//
 	_elements[i]->from_any (el);
     }
     r = value.seq_get_end ();
@@ -1855,7 +1907,7 @@ DynSequence_impl::to_any ()
 {
     CORBA::Any *a = new CORBA::Any;
 
-    a->type (_type);
+    a->set_type (_type);
     CORBA::Boolean r = a->seq_put_begin (_length);
     assert (r);
     for (CORBA::ULong i = 0; i < _elements.size(); ++i) {
@@ -1985,6 +2037,12 @@ DynArray_impl::DynArray_impl (const CORBA::Any &a)
 	CORBA::Any el;
 	r = a.any_get (el);
 	assert (r);
+// Here it is needed to set the Any type after calling any_get()
+// else there is no deal with aliased typecodes.
+// Note that calling el.set_type() before calling any_get() doesn't resolve the alias problem.
+	CORBA::TypeCode_var member_tc = tc->content_type();
+	el.type(member_tc);
+//
 	_elements.push_back (_factory()->create_dyn_any (el));
     }
     r = a.array_get_end ();
@@ -2009,6 +2067,12 @@ DynArray_impl::from_any (const CORBA::Any& value)
 	CORBA::Any el;
 	r = value.any_get (el);
 	assert (r);
+// Here it is needed to set the Any type after calling any_get()
+// else there is no deal with aliased typecodes.
+// Note that calling el.set_type() before calling any_get() doesn't resolve the alias problem.
+	CORBA::TypeCode_var member_tc = tc->unalias()->content_type();
+	el.type(member_tc);
+//
 	_elements[i]->from_any (el);
     }
     r = value.array_get_end ();
@@ -2020,7 +2084,7 @@ DynArray_impl::to_any ()
 {
     CORBA::Any *a = new CORBA::Any;
 
-    a->type (_type);
+    a->set_type (_type);
     CORBA::Boolean r = a->array_put_begin ();
     assert (r);
     for (CORBA::ULong i = 0; i < _elements.size(); ++i) {
@@ -2074,7 +2138,7 @@ DynArray_impl::set_elements_as_dyn_any (const DynamicAny::DynAnySeq& value)
 	mico_throw (TypeMismatch ());
 
     for (CORBA::ULong i = 0; i < _elements.size(); ++i)
-	_elements[i]->assign (value[i]);
+	_elements[i]->assign (value[i].in());
 }
 
 
@@ -2130,6 +2194,12 @@ DynValue_impl::DynValue_impl (const CORBA::Any &a)
 	CORBA::Any el;
 	CORBA::Boolean r = a.any_get (el);
 	assert (r);
+// Here it is needed to set the Any type after calling any_get()
+// else there is no deal with aliased typecodes.
+// Note that calling el.set_type() before calling any_get() doesn't resolve the alias problem.
+	CORBA::TypeCode_var member_tc = tc->member_type_inherited(i);
+	el.type(member_tc);
+//
 	_elements.push_back (_factory()->create_dyn_any (el));
     }
 
@@ -2176,6 +2246,12 @@ DynValue_impl::from_any (const CORBA::Any& a)
     CORBA::TypeCode_ptr tc2 = tc->unalias();
     for (CORBA::ULong i = 0; i < tc2->member_count_inherited(); ++i) {
 	CORBA::Any el;
+// Here it is needed to set the Any type before calling any_get()
+// else there is no deal with aliased typecodes.
+// Note that calling el.set_type() before calling any_get() doesn't resolve the alias problem.
+	CORBA::TypeCode_var member_tc = tc2->member_type_inherited(i);
+	el.type(member_tc);
+//
 	CORBA::Boolean r = a.any_get (el);
 	assert (r);
 	_elements[i]->from_any (el);
@@ -2195,7 +2271,7 @@ DynValue_impl::to_any ()
 {
     CORBA::Any *a = new CORBA::Any;
 
-    a->type (_type);
+    a->set_type (_type);
 
     CORBA::Long value_id;
 
@@ -2295,7 +2371,7 @@ DynValue_impl::set_members_as_dyn_any (
 	if (strlen (value[i].id) > 0 &&
             strcmp (tc->member_name_inherited(i), value[i].id))
 	    mico_throw (TypeMismatch ());
-	_elements[i]->assign (value[i].value);
+	_elements[i]->assign (value[i].value.in());
     }
     _index = _elements.size() > 0 ? 0 : -1;
 }
