@@ -1435,7 +1435,7 @@ public:
 	    return FALSE;
 	((_MICO_T *)v)->length (len);
 	for (CORBA::ULong i = 0; i < len; ++i)
-	    if (!dc.get_wstring ((*(_MICO_T *)v)[i]))
+	    if (!dc.get_wstring ((*(_MICO_T *)v)[i].out()))
 		return FALSE;
 	return dc.seq_end();
     }
@@ -1480,7 +1480,7 @@ public:
 	    return FALSE;
 	((_MICO_T *)v)->length (len);
 	for (CORBA::ULong i = 0; i < len; ++i)
-	    if (!CORBA::_stc_Object->demarshal (dc, &((*(_MICO_T *)v)[i]).inout()))
+	    if (!CORBA::_stc_Object->demarshal (dc, &((*(_MICO_T *)v)[i])._for_demarshal()))
 		return FALSE;
 	return dc.seq_end();
     }
@@ -1525,7 +1525,7 @@ public:
 	    return FALSE;
 	((_MICO_T *)v)->length (len);
 	for (CORBA::ULong i = 0; i < len; ++i)
-	    if (!CORBA::_stc_ValueBase->demarshal (dc, &((*(_MICO_T*)v)[i]).inout()))
+	    if (!CORBA::_stc_ValueBase->demarshal (dc, &((*(_MICO_T*)v)[i])._for_demarshal()))
 		return FALSE;
 	return dc.seq_end();
     }
@@ -1570,7 +1570,7 @@ public:
 	    return FALSE;
 	((_MICO_T *)v)->length (len);
 	for (CORBA::ULong i = 0; i < len; ++i)
-	    if (!CORBA::_stc_AbstractBase->demarshal (dc, &((*(_MICO_T*)v)[i]).inout()))
+	    if (!CORBA::_stc_AbstractBase->demarshal (dc, &((*(_MICO_T*)v)[i])._for_demarshal()))
 		return FALSE;
 	return dc.seq_end();
     }
@@ -2173,13 +2173,17 @@ CORBA::StaticRequest::invoke ()
 		 * invocation.
 		 */
 		CORBA::SystemException *sysex =
-		    CORBA::SystemException::EXCEPTION_DOWNCAST (exception());
+		    CORBA::SystemException::_downcast (exception());
 		assert (sysex);
-		if (sysex->completed() == CORBA::COMPLETED_NO) {
-		    _obj->_unforward();
-		    env()->clear();
-		    msgid = orb->invoke_async (_obj, this, Principal::_nil());
-		    break;
+		if (sysex->completed() == CORBA::COMPLETED_NO &&
+                    (CORBA::COMM_FAILURE::_downcast (sysex) ||
+                     CORBA::TRANSIENT::_downcast (sysex) ||
+                     CORBA::OBJECT_NOT_EXIST::_downcast (sysex))) {
+                    _obj->_unforward();
+                    env()->clear();
+                    msgid = orb->invoke_async (_obj, this,
+                                               Principal::_nil());
+                    break;
 		}
 	    }
 	    done = TRUE;
@@ -2290,11 +2294,15 @@ CORBA::StaticRequest::get_response ()
 		CORBA::SystemException *sysex =
 		    CORBA::SystemException::_downcast (exception());
 		assert (sysex);
-		if (sysex->completed() == CORBA::COMPLETED_NO) {
-		    _obj->_unforward();
-		    env()->clear();
-		    _msgid = orb->invoke_async (_obj, this, Principal::_nil());
-		    break;
+		if (sysex->completed() == CORBA::COMPLETED_NO &&
+                    (CORBA::COMM_FAILURE::_downcast (sysex) ||
+                     CORBA::TRANSIENT::_downcast (sysex) ||
+                     CORBA::OBJECT_NOT_EXIST::_downcast (sysex))) {
+                    _obj->_unforward();
+                    env()->clear();
+                    _msgid = orb->invoke_async (_obj, this,
+                                               Principal::_nil());
+                    break;
 		}
 	    }
 	    done = TRUE;
@@ -2365,7 +2373,7 @@ CORBA::StaticServerRequest::~StaticServerRequest ()
         // tell OA we are done
         CORBA::InvokeStatus stat = CORBA::InvokeOk;
         if (_env.exception()) {
-            if (CORBA::SystemException::EXCEPTION_DOWNCAST (_env.exception())) {
+            if (CORBA::SystemException::_downcast (_env.exception())) {
                 stat = CORBA::InvokeSysEx;
             } else {
                 stat = CORBA::InvokeUsrEx;
@@ -2445,6 +2453,9 @@ CORBA::StaticServerRequest::read_args ()
 void
 CORBA::StaticServerRequest::write_results ()
 {
+    // clear service context list
+    _req->context()->length (0);
+
     /*
      * must call write_results() before the method implementation
      * is left in order to write back results into ORBRequest ...
