@@ -128,7 +128,7 @@ DII::getValue (CORBA::Any &a, ConceptualGraph *rootcg, int level)
 		if (CORBA::is_nil (tc))
 		    return false;
 		a.reset ();
-		a.type (tc);
+		a.set_type (tc);
 	    }
 	    if (!a.struct_put_begin())
 		return false;
@@ -146,7 +146,7 @@ DII::getValue (CORBA::Any &a, ConceptualGraph *rootcg, int level)
 		if (CORBA::is_nil (tc))
 		    return false;
 		a.reset ();
-		a.type (tc);
+		a.set_type (tc);
 	    }
 	    cg = cg->getWidth();
 	    if (!cg)
@@ -221,7 +221,7 @@ DII::setValue (CORBA::Any &a, ConceptualGraph *rootcg, int level)
 		return false;
 	    setInst (cn, b ? "TRUE" : "FALSE");
 	} else if (type == "OBJREF") {
-	    CORBA::Object_ptr obj;
+	    CORBA::Object_var obj;
 	    if (!(a >>= CORBA::Any::to_object (obj)))
 		return false;
 	    if (CORBA::is_nil (obj)) {
@@ -387,7 +387,7 @@ DII::checkOp (CORBA::Object_ptr obj, CORBA::Request_ptr req)
     if (!irtc->subtype (optc))
 	return DIIError ("wrong result type");
 
-    for (int i = 0; i < params->length(); ++i) {
+    for (CORBA::ULong i = 0; i < params->length(); ++i) {
 	optc = req->arguments()->item(i)->value()->type();
 	irtc = params[i].type;
 	CORBA::Flags f = req->arguments()->item(i)->flags();
@@ -485,9 +485,7 @@ DII::getKey (CORBA::Object_ptr obj)
 DIIError
 DII::bind (const string &objspec, string &key_ret)
 {
-    int oargc = 0;
-    char **oargv;
-    CORBA::ORB_ptr orb = CORBA::ORB_init (oargc, oargv, "mico-local-orb");
+    CORBA::ORB_ptr orb = CORBA::ORB_instance ("mico-local-orb");
     CORBA::Object_var obj = orb->bind (objspec.c_str(), "local:");
     if (CORBA::is_nil (obj))
 	return DIIError (string("no such repository id: ") + objspec);
@@ -548,7 +546,7 @@ DII::invoke (const string &key, ConceptualGraph *cg)
             if (CORBA::is_nil (tc)) {
 		return DIIError ("missing or bad value for result");
             }
-            req->result()->value()->type (tc);
+            req->result()->value()->set_type (tc);
             CORBA::release (tc);
 	} else {
 	    cgp = findNode (args, "NAME");
@@ -612,7 +610,7 @@ DII::invoke (const string &key, ConceptualGraph *cg)
     req->invoke();
     if (CORBA::Exception *ex = req->env()->exception()) {
 	CORBA::UnknownUserException *uuex =
-	    CORBA::UnknownUserException::EXCEPTION_DOWNCAST (ex);
+	    CORBA::UnknownUserException::_downcast (ex);
 	if (uuex)
 	    return DIIError (string("user exception: ") +
 			     uuex->_except_repoid());
